yt.geometry.coordinates package
===============================

Submodules
----------

.. toctree::
   :maxdepth: 4

   yt.geometry.coordinates.api
   yt.geometry.coordinates.cartesian_coordinates
   yt.geometry.coordinates.coordinate_handler
   yt.geometry.coordinates.cylindrical_coordinates
   yt.geometry.coordinates.geographic_coordinates
   yt.geometry.coordinates.polar_coordinates
   yt.geometry.coordinates.spec_cube_coordinates
   yt.geometry.coordinates.spherical_coordinates

Module contents
---------------

.. automodule:: yt.geometry.coordinates
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
